package com.ruoyi.system.service;

import com.ruoyi.system.domain.GtgsywOld;
import java.util.List;

/**
 * 个体字号Service接口
 * 
 * @author xu
 * @date 2019-12-04
 */
public interface IGtgsywOldService 
{
    /**
     * 查询个体字号
     * 
     * @param id 个体字号ID
     * @return 个体字号
     */
    public GtgsywOld selectGtgsywOldById(Long id);

    /**
     * 查询个体字号列表
     * 
     * @param gtgsywOld 个体字号
     * @return 个体字号集合
     */
    public List<GtgsywOld> selectGtgsywOldList(GtgsywOld gtgsywOld);

    /**
     * 新增个体字号
     * 
     * @param gtgsywOld 个体字号
     * @return 结果
     */
    public int insertGtgsywOld(GtgsywOld gtgsywOld);

    /**
     * 修改个体字号
     * 
     * @param gtgsywOld 个体字号
     * @return 结果
     */
    public int updateGtgsywOld(GtgsywOld gtgsywOld);

    /**
     * 批量删除个体字号
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteGtgsywOldByIds(String ids);

    /**
     * 删除个体字号信息
     * 
     * @param id 个体字号ID
     * @return 结果
     */
    public int deleteGtgsywOldById(Long id);

    /**
     *
     * @param olds
     * @param updateSupport
     * @return
     */
    public String importOld(List<GtgsywOld>olds,Boolean updateSupport);
}
